FlutterTwilioConversationsPlatform class abstract
The interface that implementations of flutter_twilio_conversations must implement.
Platform implementations that live in a separate package should extend this
class rather than implement it as flutter_twilio_conversations does not consider newly
added methods to be breaking changes. Extending this class (using extends)
ensures that the subclass will get the default implementation, while
platform implementations that implements this interface will be broken by
newly added FlutterTwilioConversationsPlatform methods.
- Inheritance
-
- Object
- PlatformInterface
- FlutterTwilioConversationsPlatform
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addByIdentity(
String channelSid, String identity) → Future< bool?> -
advanceLastReadMessageIndexWithResult(
String channelSid, int lastReadMessageIndex) → Future< int?> -
channelStream(
String sid) → Stream< Map> ? - This stream is used to update the Channel in a plugin implementation.
-
chatClientStream(
) → Stream< Map> ? - This stream is used to update the ChatClient in a plugin implementation.
-
createChannel(
String friendlyName, String channelType) → Future< Map> -
createChatClient(
String token, Map< String, Object> properties) → Future -
declineInvitationChannel(
String channelSid) → Future< void> -
destroyChannel(
String channelSid) → Future< void> -
getAndSubscribeUser(
String identity) → Future -
getChannel(
String channelSidOrUniqueName) → Future -
getChannelUserDescriptors(
String channelSid) → Future -
getDownloadURL(
String channelSid, int messageIndex) → Future< String> -
getFriendlyNameChannel(
String channelSid) → Future< String> -
getLastMessages(
int count, String channelSid) → Future -
getMember(
String channelSid, String identity) → Future -
getMembersByIdentity(
String identity) → Future -
getMembersCountChannel(
String channelSid) → Future< int> -
getMembersList(
String channelSid) → Future -
getMessageByIndex(
String channelSid, int messageIndex) → Future -
getMessagesAfter(
int index, int count, String channelSid) → Future -
getMessagesBefore(
int index, int count, String channelSid) → Future -
getMessagesCount(
String channelSid) → Future< int> -
getNotificationLevelChannel(
String channelSid) → Future< String> -
getPublicChannelsList(
) → Future -
getUniqueNameChannel(
String channelSid) → Future< String> -
getUnreadMessagesCount(
String channelSid) → Future< int?> -
getUserChannelsList(
) → Future -
getUserDescriptor(
String identity) → Future -
handleReceivedNotification(
) → Future< void> -
inviteByIdentity(
String channelSid, String identity) → Future< bool?> -
joinChannel(
String channelSid) → Future< void> -
leaveChannel(
String channelSid) → Future< void> -
memberGetAndSubscribeUser(
String? identity, String? sid) → Future -
memberGetUserDescriptor(
String? identity, String? channelSid) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notificationStream(
) → Stream< Map> ? - This stream is used to update the Notification in a plugin implementation.
-
platformDebug(
bool dart, bool native, bool sdk) → Future< void> -
registerForNotification(
String token, {String? webChannel}) → Future< String> -
removeByIdentity(
String channelSid, String identity) → Future< bool?> -
removeMessage(
String channelSid, int messageIndex) → Future< void> -
requestNextPage(
String pageId, String itemType) → Future -
sendMessage(
Map< String, dynamic> messageOptions, String channelSid) → Future -
setAllMessagesReadWithResult(
String channelSid) → Future< int?> -
setAttributes(
String? channelSid, int? messageIndex, Map< String, dynamic> attributes) → Future -
setAttributesChannel(
String channelSid, Map< String, dynamic> attributes) → Future<Map< String, dynamic> > -
setAttributesMember(
String sid, String? channelSid, Map< String, dynamic> attributes) → Future -
setFriendlyNameChannel(
String channelSid, String friendlyName) → Future< String> -
setLastReadMessageIndexWithResult(
String channelSid, int lastReadMessageIndex) → Future< int?> -
setNoMessagesReadWithResult(
String channelSid) → Future< int?> -
setNotificationLevelChannel(
String channelSid, String notificationLevel) → Future< String> -
setUniqueNameChannel(
String channelSid, String uniqueName) → Future< String> -
shutdown(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
typingChannel(
String channelSid) → Future< void> -
unregisterForNotification(
String token, {String? webChannel}) → Future< void> -
unsubscribe(
String? identity) → Future< void> -
updateMessageBody(
String? channelSid, int? messageIndex, String body) → Future< String> -
updateToken(
String token) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterTwilioConversationsPlatform
-
Platform-specific plugins should override this with their own
platform-specific class that extends FlutterTwilioConversationsPlatform when they
register themselves.
getter/setter pair